<?php

/**
 * @file DomainFinderAdminForm.php
 * 
 * Definition of Drupal\domain_finder\Form\DomainFinderAdminForm.
 */

namespace Drupal\domain_finder\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Form controller for the content_entity_example entity edit forms.
 *
 * @ingroup content_entity_example
 */
class DomainFinderAdminForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['domain_finder.settings'];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'domain_finder_admin_form';
  }

  /**
   * Define the form used for domain finder settings.
   * @return array
   *   Form definition array.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param FormStateInterface $form_state
   *   An associative array containing the current state of the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('domain_finder.settings');

    $form = array();
    require_once drupal_get_path('module', 'domain_finder') . '/includes/domain_finder.domains.inc';

    $form['help'] = array(
      '#markup' => $this->t('This configuration page provide the domain extension list.So please choose the domain extensions you want to find.'),
    );

    $form['domain_finder_domains_in_form'] = array(
      '#type' => 'checkbox',
      '#title' => $this->t('Show checkboxes on domain finder form'),
      '#default_value' => $config->get('domains_in_form'),
    );

    $available_domains = domain_finder_get_domains();
    $form['domain_finder_domains'] = array(
      '#type' => 'checkboxes',
      '#title' => $this->t('Available domain extensions'),
      '#options' => array_combine($available_domains['basic']['domains'], $available_domains['basic']['domains']),
      '#default_value' => $config->get('domains'),
    );

    return parent::buildForm($form, $form_state);
  }

  /**
   * Form validation handler.
   *
   * @param FormStateInterface $form
   *   An associative array containing the structure of the form.
   * @param array $form_state
   *   An associative array containing the current state of the form.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $domain_exts = array_filter($form_state->getValue('domain_finder_domains'));
    if (empty($domain_exts)) {
      $form_state->setErrorByName('domain_finder_domains', $this->t('Please chose least one domain extension from list.'));
    }
  }

  /**
   * Form submission handler.
   *
   * @param FormStateInterface $form
   *   An associative array containing the structure of the form.
   * @param array $form_state
   *   An associative array containing the current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('domain_finder.settings')
    ->set('domains_in_form', $form_state->getValue('domain_finder_domains_in_form'))
    ->set('domains', $form_state->getValue('domain_finder_domains'))
    ->save();
    
    parent::submitForm($form, $form_state);
  }

}
