<?php

/**
 * @file DomainFinderSearchForm.php
 * 
 * Definition of Drupal\domain_finder\Form\DomainFinderSearchForm.
 */

namespace Drupal\domain_finder\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Component\Utility\SafeMarkup;

/**
 * Form controller for the content_entity_example entity edit forms.
 *
 * @ingroup content_entity_example
 */
class DomainFinderSearchForm extends FormBase {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'domain_finder_search_form';
  }

  /**
   * Overrides Drupal\Core\Entity\EntityFormController::buildForm().
   */
  public function buildForm(array $form, FormStateInterface $form_state, $config = NULL) {

    $in_form = FALSE;
    $exts = array();
    if (!is_array($config)) {
      $in_form = \Drupal::config('domain_finder.settings')->get('domains_in_form');
      $exts = \Drupal::config('domain_finder.settings')->get('domains');
    }
    else {
      $in_form = $config['domains_in_form'];
      $exts = $config['domains'];
      $form['config'] = array(
        '#type' => 'hidden',
        '#value' => $config,
      );
    }

    $form['domain_text'] = array(
      '#type' => 'textfield',
      '#default_value' => isset($_GET['domain_text']) ? $_GET['domain_text'] : '',
    );

    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Search'),
    );

    if (!empty($in_form)) {
      $form['exts'] = array(
        '#type' => 'container',
        '#tree' => TRUE,
      );
      foreach (array_filter($exts) as $domain) {
        if (empty($_GET) || $_GET['q'] != 'domain_finder') {
          $value = 1;
        }
        else {
          $value = isset($_GET[$domain]) ? $_GET[$domain] : 0;
        }
        $form['exts'][$domain] = array(
          '#type' => 'checkbox',
          '#title' => SafeMarkup::checkPlain(".$domain"),
          '#default_value' => $value,
        );
      }
    }

    //@TODO Need domain_finder.css to formatting form.
    //$form['#attached']['css'] = array(drupal_get_path('module', 'domain_finder') . '/domain_finder.css');

    return $form;
  }

  /**
   * Form submission handler.
   *
   * @param FormStateInterface $form
   *   An associative array containing the structure of the form.
   * @param array $form_state
   *   An associative array containing the current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $query = array('domain_text' => $form_state->getValue('domain_text'));
    $query['domain_in_form'] = $form_state->getValue('config')['domains_in_form'];
    $domains = $form_state->getValue('exts');

    $query['domains'] = array();
    if (!empty($domains)) {
      if ($query['domain_in_form'] !== 0) {
        $domains = array_filter($domains);
      }
      foreach (array_keys($domains) as $domain) {
        $query['domains'][] = $domain;
      }
    }

    $form_state->setRedirect('domain_finder.view', $query);
  }

}
